@@ -1,12 +1,12 @@
 /* Copyright (c) 2002,2003 CrystalClear Software, Inc.
  * Use, modification and distribution is subject to the 
  * Boost Software License, Version 1.0. (See accompanying
- * file LICENSE-1.0 or http://www.boost.org/LICENSE-1.0)
+ * file LICENSE_1_0.txt or http://www.boost.org/LICENSE_1_0.txt)
  * Author: Jeff Garland 
  */
 
 #include "boost/date_time/gregorian/greg_year.hpp"
-#include "boost/date_time/testfrmwk.hpp"
+#include "../testfrmwk.hpp"
 #include <iostream>
 
 
@@ -39,8 +39,8 @@ main()
     check("Bad year creation2", true); //good
     
   }
-  check("traits min year", greg_year::min() ==  1400);
-  check("traits max year", greg_year::max() == 10000);
+  check("traits min year", (greg_year::min)() ==  1400);
+  check("traits max year", (greg_year::max)() == 10000);
 
   printTestStats();
   return 0;
